@@ -506,6 +506,15 @@ class Auth(object):
         })
         return Hosts(**params)
 
+    def igneous(self):
+        """Connect to Igneous api."""
+        from bitsapiclient.services.igneous import Igneous
+        params = self.secrets.resolve({
+            'server': self.settings['igneous']['server'],
+            'api_key': self.settings['igneous']['api_key'],
+        })
+        return Igneous(**params)
+
     def intranet(self):
         """Connect to Intranet DB."""
         from bitsapiclient.services.iwww import IWWW
